{image filename="context-free-tree-screenshot.png" alt="A tree drawn using the software from contextfreeart.org" source="http://contextfreeart.org/"}

The context free art program (http://www.contextfreeart.org/) enables you to specify images using a context-free grammar. For example, the following pictures of trees are defined by just a few rules that are based around a forest being made of trees, a tree being made of branches, and the branches in turn being made of branches themselves! These simple definitions can create images with huge amounts of detail because the drawing process can break down the grammar into as many levels as required. You can define your own grammars to generate images, and even make a movie of them being created, like the one below. Of course, if you do this as a project make sure you understand how the system works and can explain the formal language behind your creation.

{comment}

.. TCB the above context-free-tree video was generated from the context-free program --- you can control the frame rate etc. if a different version is needed. It is just "demo1" in the program. Music is from a song by Andrew Bell

{comment end}